# Hello World

This is an example project demonstrating how to publish a python module to PyPI.py

## Installation

Run the following to install:

'''python
pip install helloworld
'''

## Usage

'''python
from helloworld import say_hello

# Generate "Hello, Everybody!"
say_hello("Everybody")
'''